@@ -31,6 +31,7 @@
 #include "nautilus-file-utilities.h"
 #include "nautilus-iso9660.h"
 #include "nautilus-volume-monitor.h"
+#include <eel/eel-debug.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
@@ -42,7 +43,6 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <libxml/tree.h>
 #include <gtk/gtkmain.h>
 #include <libgnome/gnome-config.h>
@@ -339,17 +339,18 @@ nautilus_volume_monitor_class_init (NautilusVolumeMonitorClass *klass)
 		                G_TYPE_NONE, 1, G_TYPE_POINTER);
 
 	/* Check environment a bit. */
-	if (g_file_exists ("/vol/dev")) {
+	if (g_file_test ("/vol/dev", G_FILE_TEST_EXISTS)) {
 		floppy_device_path_prefix = "/vol/dev/diskette/";
 	} else {
 		floppy_device_path_prefix = "/dev/fd";
 	}
-	if (g_file_exists ("/vol")) {
+	if (g_file_test ("/vol", G_FILE_TEST_EXISTS)) {
 		noauto_string = "/vol/";
 	} else {
 		noauto_string = "/dev/fd";
 	}
-	mnttab_exists = g_file_exists ("/etc/mnttab");
+	mnttab_exists = g_file_test ("/etc/mnttab",
+				     G_FILE_TEST_EXISTS);
 }
 
 static void
@@ -395,7 +396,7 @@ nautilus_volume_monitor_get (void)
 					 NULL));
 		g_object_ref (global_volume_monitor);
 		gtk_object_sink (GTK_OBJECT (global_volume_monitor));
-		g_atexit (unref_global_volume_monitor);
+		eel_debug_call_at_shutdown (unref_global_volume_monitor);
 	}
 
 	return global_volume_monitor;
@@ -892,6 +893,7 @@ mount_volume_deactivate (NautilusVolumeMonitor *monitor, NautilusVolume *volume)
 		}
 		break;
 	default:
+		break;
 	}
 
 	g_signal_emit (monitor,
@@ -1378,7 +1380,7 @@ find_command (const char **known_locations)
 	int i;
 
 	for (i = 0; known_locations [i]; i++){
-		if (g_file_exists (known_locations [i]))
+		if (g_file_test (known_locations [i], G_FILE_TEST_EXISTS))
 			return known_locations [i];
 	}
 	return NULL;
