@@ -306,7 +306,7 @@ void                fm_directory_view_reset_to_defaults                (FMDirect
 void                fm_directory_view_select_all                       (FMDirectoryView  *view);
 void                fm_directory_view_set_selection                    (FMDirectoryView  *view,
 									GList            *selection);
-GArray *            fm_directory_get_selected_icon_locations           (FMDirectoryView  *view);
+GArray *            fm_directory_view_get_selected_icon_locations      (FMDirectoryView  *view);
 void                fm_directory_view_reveal_selection                 (FMDirectoryView  *view);
 gboolean            fm_directory_view_is_empty                         (FMDirectoryView  *view);
 gboolean            fm_directory_view_is_read_only                     (FMDirectoryView  *view);
