@@ -28,8 +28,10 @@
 #include "libnautilus-private/nautilus-global-preferences.h"
 #include "libnautilus-private/nautilus-sidebar-functions.h"
 #include "nautilus-theme-selector.h"
+#include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-preferences-box.h>
+#include <gtk/gtkdialog.h>
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
@@ -49,19 +51,9 @@ static void preferences_dialog_populate_themes_group       (EelPreferencesGroup
 static GtkWidget *preferences_dialog;
 
 static EelPreferencesItemDescription appearance_items[] = {
-	{ N_("Smoother Graphics"),
-	  NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE,
-	  N_("Use smoother (but slower) graphics"),
-	  EEL_PREFERENCE_ITEM_BOOLEAN
-	},
-	{ N_("Fonts"),
-	  NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
-	  N_("Default smooth font:"),
-	  EEL_PREFERENCE_ITEM_SMOOTH_FONT,
-	},
 	{ N_("Fonts"),
 	  NAUTILUS_PREFERENCES_DEFAULT_FONT,
-	  N_("Default non-smooth font:"),
+	  N_("Default font:"),
 	  EEL_PREFERENCE_ITEM_FONT,
 	},
 	{ N_("Nautilus Themes"),
@@ -204,16 +196,7 @@ static EelPreferencesItemDescription view_preferences_items[] = {
 	{ N_("Icon View Defaults"),
 	  NAUTILUS_PREFERENCES_ICON_VIEW_FONT,
 	  N_("Font:"),
-	  EEL_PREFERENCE_ITEM_FONT,
-	  NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE,
-	  EEL_PREFERENCE_ITEM_HIDE
-	},
-	{ N_("Icon View Defaults"),
-	  NAUTILUS_PREFERENCES_ICON_VIEW_SMOOTH_FONT,
-	  N_("Font:"),
-	  EEL_PREFERENCE_ITEM_SMOOTH_FONT,
-	  NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE,
-	  EEL_PREFERENCE_ITEM_SHOW
+	  EEL_PREFERENCE_ITEM_FONT
 	},
 	{ N_("Icon View Defaults"),
 	  NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
@@ -271,21 +254,16 @@ static EelPreferencesItemDescription view_preferences_items[] = {
 	{ NULL }
 };
 
-static EelPreferencesItemDescription search_items[] = {
 #ifdef HAVE_MEDUSA
+static EelPreferencesItemDescription search_items[] = {
 	{ N_("Search Complexity Options"),
 	  NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
 	  N_("search type to do by default"),
 	  EEL_PREFERENCE_ITEM_ENUMERATION_VERTICAL_RADIO
 	},
-#endif
-	{ N_("Search Engines"),
-	  NAUTILUS_PREFERENCES_SEARCH_WEB_URI,
-	  N_("Search Engine Location"),
-	  EEL_PREFERENCE_ITEM_EDITABLE_STRING
-	},
 	{ NULL }
 };
+#endif
 
 static EelPreferencesItemDescription navigation_items[] = {
 	{ N_("Home"),
@@ -414,7 +392,9 @@ static EelPreferencesPaneDescription panes[] = {
 	{ N_("Icon & List Views"),	  directory_views_items },
 	{ N_("Icon Captions"),		  icon_captions_items },
 	{ N_("Sidebar Panels"),		  sidebar_items },
+#ifdef HAVE_MEDUSA
 	{ N_("Search"),			  search_items },
+#endif
 	{ N_("Navigation"),		  navigation_items },
 	{ N_("Speed Tradeoffs"),	  tradeoffs_items },
 	{ N_("News Panel"),		  news_panel_items },
@@ -422,21 +402,19 @@ static EelPreferencesPaneDescription panes[] = {
 };
 
 static void
-dialog_button_clicked_callback (GnomeDialog *dialog,
-				gint n,
-				gpointer callback_data)
+dialog_delete_event_callback (GtkWidget   *widget,
+			      GdkEventAny *event,
+			      gpointer     user_data)
 {
-	g_return_if_fail (GNOME_IS_DIALOG (dialog));
-	gtk_widget_hide (GTK_WIDGET (dialog));
+	gtk_widget_hide (widget);
 }
 
-static gboolean
-dialog_close_callback (GtkWidget *dialog,
-		       gpointer user_data)
+static void
+dialog_button_response_callback (GtkDialog *dialog,
+				 int response_id,
+				 gpointer callback_data)
 {
-	g_return_val_if_fail (GNOME_IS_DIALOG (dialog), TRUE);
-	gtk_widget_hide (dialog);
-	return TRUE;
+	gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
 static GtkWidget *
@@ -445,18 +423,19 @@ preferences_dialog_create (void)
 	GtkWidget *dialog;
 
 	dialog = eel_preferences_dialog_new (_("Preferences"), panes);
+	g_assert (GTK_IS_DIALOG (dialog));
 
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), "nautilus_preferences", "Nautilus");
 
-	gtk_signal_connect (GTK_OBJECT (dialog),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (dialog_button_clicked_callback),
-			    dialog);
+	g_signal_connect (dialog,
+			  "delete_event",
+			  G_CALLBACK (dialog_delete_event_callback),
+			  dialog);
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (dialog_button_response_callback),
+			  dialog);
 
-	gtk_signal_connect (GTK_OBJECT (dialog),
-			    "close",
-			    GTK_SIGNAL_FUNC (dialog_close_callback),
-			    NULL);
 	return dialog;
 }
 
@@ -554,17 +533,17 @@ preferences_dialog_populate_themes_group (EelPreferencesGroup *group)
 						      "theme_changed",
 						      0);
 	/* Keep track of theme chooser changes */
-	gtk_signal_connect (GTK_OBJECT (child),
+	g_signal_connect (child,
 			    "theme_changed",
-			    GTK_SIGNAL_FUNC (theme_changed_callback),
+			    G_CALLBACK (theme_changed_callback),
 			    NULL);
 
 	/* Have the custom preferences item tell us when its time to update the displayed
 	 * with with the one stored in preferences
 	 */
-	gtk_signal_connect (GTK_OBJECT (item),
+	g_signal_connect (item,
 			    "custom_update_displayed_value",
-			    GTK_SIGNAL_FUNC (update_theme_selector_displayed_value_callback),
+			    G_CALLBACK (update_theme_selector_displayed_value_callback),
 			    child);
 	update_theme_selector_displayed_value_callback (EEL_PREFERENCES_ITEM (item), child);
 }
@@ -584,24 +563,19 @@ preferences_dialog_destroy (void)
 static GtkWidget *
 global_preferences_get_dialog (void)
 {
-	nautilus_global_preferences_initialize ();
+	nautilus_global_preferences_init ();
 	
 	if (preferences_dialog == NULL) {
 		preferences_dialog = preferences_dialog_create ();
-		g_atexit (preferences_dialog_destroy);
+		eel_debug_call_at_shutdown (preferences_dialog_destroy);
 	}
 
-	g_return_val_if_fail (GNOME_IS_DIALOG (preferences_dialog), NULL);
+	g_assert (GTK_IS_DIALOG (preferences_dialog));
 	return preferences_dialog;
 }
 
 void
 nautilus_preferences_dialog_show (void)
 {
-	GtkWidget *dialog;
-
-	dialog = global_preferences_get_dialog ();
-	g_return_if_fail (GNOME_IS_DIALOG (dialog));
-
-	eel_gtk_window_present (GTK_WINDOW (dialog));
+	gtk_window_present (GTK_WINDOW (global_preferences_get_dialog ()));
 }
