@@ -117,7 +117,6 @@ static void     nautilus_sidebar_drag_data_received    (GtkWidget        *widget
 static void     nautilus_sidebar_read_theme            (NautilusSidebar  *sidebar);
 static void     nautilus_sidebar_size_allocate         (GtkWidget        *widget,
 							GtkAllocation    *allocation);
-static void     nautilus_sidebar_realize               (GtkWidget        *widget);
 static void     nautilus_sidebar_theme_changed         (gpointer          user_data);
 static void     nautilus_sidebar_confirm_trash_changed (gpointer          user_data);
 static void     nautilus_sidebar_update_appearance     (NautilusSidebar  *sidebar);
@@ -195,7 +194,6 @@ nautilus_sidebar_class_init (GtkObjectClass *object_klass)
 	widget_class->button_press_event  = nautilus_sidebar_press_event;
 	widget_class->button_release_event  = nautilus_sidebar_release_event;
 	widget_class->size_allocate = nautilus_sidebar_size_allocate;
-	widget_class->realize = nautilus_sidebar_realize;
 
 	/* add the "location changed" signal */
 	signals[LOCATION_CHANGED] = g_signal_new
@@ -1366,13 +1364,6 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 				    FALSE, FALSE, 
 				    0);
 
-		/* FIXME bugzilla.gnome.org 42510: Security hole?
-		 * Unsafe to use a string from the MIME file as a
-		 * printf format string without first checking it over
-		 * somehow. We can do a search and replace on the "%s"
-		 * part instead, which should work.
-		 */
-
 		/* Get the local path, if there is one */
 		file_path = gnome_vfs_get_local_path_from_uri (sidebar->details->uri);
 		if (file_path == NULL) {
@@ -1380,7 +1371,7 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 		} 
 
 		temp_str = g_shell_quote (file_path);		
-		id_string = g_strdup_printf (application->id, temp_str); 		
+		id_string = eel_str_replace_substring (application->id, "%s", temp_str); 		
 		g_free (file_path);
 		g_free (temp_str);
 
@@ -1703,15 +1694,3 @@ nautilus_sidebar_size_allocate (GtkWidget *widget,
 					     widget->allocation.width);
 	}	
 }
-
-static void
-nautilus_sidebar_realize (GtkWidget *widget)
-{
-	g_return_if_fail (NAUTILUS_IS_SIDEBAR (widget));
-	
-	/* Superclass does the actual realize */
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
-	
-	/* Tell X not to erase the window contents when resizing */
-	gdk_window_set_static_gravities (widget->window, TRUE);
-}
