@@ -29,7 +29,6 @@
 
 #include <locale.h> 
 
-#include "nautilus-about.h"
 #include "nautilus-application.h"
 #include "nautilus-bookmark-list.h"
 #include "nautilus-bookmark-parsing.h"
@@ -50,10 +49,10 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <gtk/gtkmain.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
+#include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -139,11 +138,11 @@ bookmark_holder_new (NautilusBookmark *bookmark,
 	new_bookmark_holder->prompt_for_removal = is_bookmarks_menu;
 
 	new_bookmark_holder->changed_handler_id = 
-		gtk_signal_connect_object (GTK_OBJECT (bookmark), "appearance_changed",
-				   	   is_bookmarks_menu
-				   	   ? G_CALLBACK (schedule_refresh_bookmarks_menu)
-				   	   : G_CALLBACK (schedule_refresh_go_menu),
-				   	   GTK_OBJECT (window));
+		g_signal_connect_swapped (bookmark, "appearance_changed",
+					  is_bookmarks_menu
+					  ? G_CALLBACK (schedule_refresh_bookmarks_menu)
+					  : G_CALLBACK (schedule_refresh_go_menu),
+					  window);
 
 	return new_bookmark_holder;
 }
@@ -151,8 +150,8 @@ bookmark_holder_new (NautilusBookmark *bookmark,
 static void
 bookmark_holder_free (BookmarkHolder *bookmark_holder)
 {
-	gtk_signal_disconnect (GTK_OBJECT (bookmark_holder->bookmark), 
-			       bookmark_holder->changed_handler_id);
+	g_signal_handler_disconnect (bookmark_holder->bookmark,
+				     bookmark_holder->changed_handler_id);
 	g_object_unref (bookmark_holder->bookmark);
 	g_free (bookmark_holder);
 }
@@ -261,14 +260,6 @@ go_menu_location_callback (BonoboUIComponent *component,
 	}
 }			   
 
-static void
-file_menu_web_search_callback (BonoboUIComponent *component, 
-			       gpointer user_data, 
-			       const char *verb)
-{
-	nautilus_window_go_web_search (NAUTILUS_WINDOW (user_data));
-}
-
 static void
 stop_button_callback (BonoboUIComponent *component, 
 			       gpointer user_data, 
@@ -587,9 +578,7 @@ help_menu_about_nautilus_callback (BonoboUIComponent *component,
 	const char *translator_credits;
 	const char *locale;
 
-	if (about != NULL) {
-		nautilus_about_update_authors (NAUTILUS_ABOUT (about));
-	} else {
+	if (about == NULL) {
 		/* The time stamp overrides the build message, because
 		 * the time stamp should only be set on Tinderbox for
 		 * hourly builds.
@@ -627,18 +616,21 @@ help_menu_about_nautilus_callback (BonoboUIComponent *component,
 		 */
 		translator_credits = _("Translator Credits");
 		
-		about = nautilus_about_new (_("Nautilus"),
-					    VERSION,
-					    copyright,
-					    authors,
-					    _("Nautilus is a graphical shell\n"
-					      "for GNOME that makes it\n"
-					      "easy to manage your files\n"
-					      "and the rest of your system."),
-					    translator_credits,
-					    build_message);
+		about = gnome_about_new (_("Nautilus"),
+					 VERSION,
+					 copyright,
+					 _("Nautilus is a graphical shell "
+					   "for GNOME that makes it "
+					   "easy to manage your files "
+					   "and the rest of your system."),
+					 authors,
+					 NULL,
+					 translator_credits,
+					 NULL);
 		
 		g_free (build_message);
+
+		eel_add_weak_pointer (&about);
 	}
 	
 	gtk_window_present (GTK_WINDOW (about));
@@ -819,12 +811,12 @@ get_static_bookmarks_file_path (void)
 	/* see if there is a static bookmarks file in the updates directory and get its mod-date */
 	user_directory_path = nautilus_get_user_directory ();
 	update_xml_file_path = g_strdup_printf ("%s/updates/%s", user_directory_path, STATIC_BOOKMARKS_FILE_NAME);
-	update_exists = g_file_exists (update_xml_file_path);
+	update_exists = g_file_test (update_xml_file_path, G_FILE_TEST_EXISTS);
 	g_free (user_directory_path);
 	
 	/* get the mod date of the built-in static bookmarks file */
 	built_in_xml_file_path = nautilus_make_path (NAUTILUS_DATADIR, STATIC_BOOKMARKS_FILE_NAME);
-	built_in_exists = g_file_exists (built_in_xml_file_path);
+	built_in_exists = g_file_test (built_in_xml_file_path, G_FILE_TEST_EXISTS);
 	
 	/* if we only have one file, return its path as the one to use */
 	if (built_in_exists && !update_exists) {
@@ -907,7 +899,7 @@ create_menu_item_from_node (NautilusWindow *window,
 		append_separator (window, menu_path);
 	} else if (strcmp (node->name, "folder") == 0) {
 		xml_folder_name = eel_xml_get_property_translated (node, "name");
-		nautilus_bonobo_add_submenu (window->details->shell_ui, menu_path, xml_folder_name);
+		nautilus_bonobo_add_submenu (window->details->shell_ui, menu_path, xml_folder_name, NULL);
 
 		/* Construct path and make sure it is escaped properly */
 		escaped_name = gnome_vfs_escape_string (xml_folder_name);
@@ -1111,7 +1103,6 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Find", file_menu_find_callback),
 		BONOBO_UI_VERB ("Toggle Find Mode", toolbar_toggle_find_mode_callback),
 #endif
-		BONOBO_UI_VERB ("Go to Web Search", file_menu_web_search_callback),
 		BONOBO_UI_VERB ("Undo", edit_menu_undo_callback),
 		BONOBO_UI_VERB ("Customize", customize_callback),
 		BONOBO_UI_VERB ("Back", go_menu_back_callback),
